/**   @file  oomstub.h
 *   @brief  C memory management diverters
 *
 *  This file implements fake malloc, free and realloc functions which can
 *  fail and simulate OOM after a countdown.
 *  This library is not threadsafe.
 *  Inspired from https://github.com/bkthomps/Containers test suite
 *
 *  @code{.c}
 *  oomstub_setcountdown(3);
 *  assert(NULL!=malloc(123));         // Success
 *  assert(NULL!=realloc(oldptr,123)); // Success
 *  assert(NULL==malloc(123));         // Failure with NULL
 *  assert(NULL!=malloc(123));         // Success
 *  assert(NULL!=malloc(123));         // Success
 *  @endcode
 *
 *  @author  François Cerbelle (Fanfan), francois@cerbelle.net
 *
 *  @internal
 *       Created:  10/12/2024
 *      Revision:  none
 * Last modified:  2024-12-11 13:10
 *      Compiler:  gcc
 *  Organization:  Cerbelle.net
 *     Copyright:  Copyright (c) 2024, François Cerbelle
 *
 *  This source code is released for free distribution under the terms of the
 *  GNU General Public License as published by the Free Software Foundation.
 */


#ifndef __OOMSTUB_H__
#define __OOMSTUB_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

void oomstub_setcountdown(const int counter);
int  oomstub_getcountdown();

#endif /* __OOMSTUB_H__ */

/* vim: set tw=80: */
